Skip to contents

Provides a lightweight R interface to the Ipopt nonlinear optimization solver through Ipopt's C interface. The package is intended for r-universe builds that provide Ipopt and its open linear solver dependencies, such as MUMPS, through system libraries discoverable by pkg-config.

Author

Maintainer: Balasubramanian Narasimhan naras@stanford.edu

Authors:

Other contributors:

  • Andreas Waechter (Main author of Ipopt; COIN-OR project manager) [contributor, copyright holder]

  • Carl Laird (Main author of Ipopt) [contributor, copyright holder]

  • Stefan Vigerske (COIN-OR project manager for Ipopt) [contributor]

  • COIN-OR Foundation (Ipopt project and copyright holder) [copyright holder]